==> lozad-1.16.0.tgz: lozad/README.md <==
# Installation
> `npm install --save @types/lozad`

# Summary
This package contains type definitions for lozad (https://github.com/ApoorvSaxena/lozad.js).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/lozad.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/lozad/index.d.ts)
````ts
// Type definitions for lozad 1.16
// Project: https://github.com/ApoorvSaxena/lozad.js
// Definitions by: York Yao <https://github.com/plantain-00>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

declare namespace lozad {
    interface Options {
        enableAutoReload?: boolean;
        rootMargin?: string;
        threshold?: number;
        load?(element: Element): void;
        loaded?(element: Element): void;
    }

    // TODO: remove on next major version bump
    // tslint:disable:next-line no-empty-interface
    interface Option extends Options {}

    interface Observer {
        observe(): void;
        triggerLoad(element: Element): void;
        observer: IntersectionObserver;
    }

    type Selector = string | Element | HTMLCollectionOf<Element> | NodeListOf<Element>;

    const prototype: {
    };
}

declare function lozad(selector?: lozad.Selector, options?: lozad.Options): lozad.Observer;

export as namespace lozad;

export = lozad;

````

### Additional Details
 * Last updated: Wed, 16 Jun 2021 12:31:20 GMT
 * Dependencies: none
 * Global values: `lozad`

# Credits
These definitions were written by [York Yao](https://github.com/plantain-00).

==> lozad-1.16.1.tgz: lozad/README.md <==
# Installation
> `npm install --save @types/lozad`

# Summary
This package contains type definitions for lozad (https://github.com/ApoorvSaxena/lozad.js).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/lozad.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/lozad/index.d.ts)
````ts
// Type definitions for lozad 1.16
// Project: https://github.com/ApoorvSaxena/lozad.js
// Definitions by: York Yao <https://github.com/plantain-00>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

declare namespace lozad {
    interface Options {
        enableAutoReload?: boolean | undefined;
        rootMargin?: string | undefined;
        threshold?: number | undefined;
        load?(element: Element): void;
        loaded?(element: Element): void;
    }

    // TODO: remove on next major version bump
    // tslint:disable:next-line no-empty-interface
    interface Option extends Options {}

    interface Observer {
        observe(): void;
        triggerLoad(element: Element): void;
        observer: IntersectionObserver;
    }

    type Selector = string | Element | HTMLCollectionOf<Element> | NodeListOf<Element>;

    const prototype: {
    };
}

declare function lozad(selector?: lozad.Selector, options?: lozad.Options): lozad.Observer;

export as namespace lozad;

export = lozad;

````

### Additional Details
 * Last updated: Thu, 08 Jul 2021 16:23:51 GMT
 * Dependencies: none
 * Global values: `lozad`

# Credits
These definitions were written by [York Yao](https://github.com/plantain-00).
